<script setup>

import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';
import PrimaryButton from '@/Components/PrimaryButton.vue';

const form = useForm({
    csv_file: '',
});
const flashMessage = ref('');
const years = generateYears(1949, new Date().getFullYear()); // Adjust the range as needed
const selectedYear = new Date().getFullYear();

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const submit = () => {
    console.log("Import submitted");
    form.post(route('admin.import.save'), {
        onSuccess: () => {
            form.reset()
            flashMessage.value = "Product added successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

</script>

<template>
    <Head title="Import Products" />

    <AdminAuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Import Products</h2>
        </template>

        <div class="py-12">

            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit" enctype="multipart/form-data">

                    <div class="form-row px-8">

                        <div class="mt-4 col-md-3">
                            <InputLabel for="csv_file" value="Choose a CSV file" />

                            <input type="file" id="csv_file" @input="form.csv_file=$event.target.files[0]" class="mt-1 block w-full" required />

                            <InputError class="mt-2" :message="form.errors.item_number" />
                        </div>
                    </div>

                    <div class="flex items-center mt-4">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Import
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>

